@@ -1,6 +1,16 @@
 #![doc = include_str!("../README.md")]
-#![doc(html_root_url = "https://docs.rs/fts-sys/0.2.13")]
-#![cfg(unix)]
+#![doc(html_root_url = "https://docs.rs/fts-sys/0.2.16")]
+#![cfg(any(
+    // This list must be kept synchronized with the check in `build.rs`.
+    target_os = "android",
+    target_os = "dragonfly",
+    target_os = "freebsd",
+    target_os = "hurd",
+    target_os = "linux",
+    target_os = "macos",
+    target_os = "netbsd",
+    target_os = "openbsd",
+))]
 #![warn(unsafe_op_in_unsafe_fn)]
 #![allow(
     non_upper_case_globals,
